==> nextcloud-22.2.4.tar.bz2: nextcloud/apps/federatedfilesharing/l10n/pt_PT.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Pretende adicionar a partilha remota {nome} de {proprietório}@{remoto}?",
    "Remote share" : "Partilha remota",
    "Remote share password" : "Palavra-passe da partilha remota",
    "Cancel" : "Cancelar",
    "Add remote share" : "Adicionar partilha remota",
    "Copy" : "Copiar",
    "Copied!" : "Copiado!",
    "Not supported!" : "Não suportado!",
    "Press ⌘-C to copy." : "Pressione ⌘-C para copiar.",
    "Press Ctrl-C to copy." : "Pressione Ctrl-C para copiar.",
    "Invalid Federated Cloud ID" : "Id. de Nuvem Federada Inválida",
    "Server to server sharing is not enabled on this server" : "Partilha servidor-para-servidor não está activa neste servidor",
    "Couldn't establish a federated share." : "Não foi possível estabelecer uma partilha federada.",
    "Couldn't establish a federated share, maybe the password was wrong." : "Não foi possível estabelecer a partilha federada, a palavra-passe talvez esteja incorrecta.",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "Pedido de Partilha Federada enviado, irá receber o convite. Confira as suas notificações.",
    "Not allowed to create a federated share with the same user" : "Não é possível criar uma partilha federada com o mesmo utilizador",
    "File is already shared with %s" : "O ficheiro já foi partilhado com %s",
    "Could not find share" : "Não foi possível encontrar partilha",
    "Federated sharing" : "Partilha Federada",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Recebeu {partilha} como uma partilha remota de {utilizador} (em nome de {behalf})",
    "You received {share} as a remote share from {user}" : "Recebeu {partilha} como uma partilha remota de {utilizador}",
    "Accept" : "Aceitar",
    "Decline" : "Recusar",
    "Federated Cloud Sharing" : "Partilha de Nuvem Federada",
    "Share with me through my #Nextcloud Federated Cloud ID, see %s" : "Partilhe comigo através da minha Id. da Nuvem Federada #Nextcloud, veja %s",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Partilhe comigo através da minha Id. da Nuvem Federada #Nextcloud",
    "Sharing" : "Partilha",
    "Federated file sharing" : "Partilha federada de ficheiros",
    "Provide federated file sharing across servers" : "Permita a partilha federada de ficheiros entre servidores",
    "Open documentation" : "Abrir documentação",
    "Allow users on this server to receive shares from other servers" : "Permitir que os utilizadores neste servidor recebam as partilhas de outros servidores",
    "Search global and public address book for users" : "Pesquisar lista global e pública de contactos de utilizadores  ",
    "Allow users to publish their data to a global and public address book" : "Permitir que  os utilizadores publiquem os seus dados para uma lista de contactos global e pública",
    "Federated Cloud" : "Nuvem Federada",
    "Your Federated Cloud ID:" : "A sua id. da Nuvem Federada:",
    "Share it so your friends can share files with you:" : "Partilhe para que os seus amigos possam partilhar ficheiros consigo:",
    "Add to your website" : "Adicione ao seu site da Web",
    "Share with me via Nextcloud" : "Partilhe comigo via Nextcloud",
    "HTML Code:" : "Código HTML:",
    "Adjust how people can share between servers." : "Ajustar como as pessoas podem partilhar entre servidores."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-29.0.15.tar.bz2: nextcloud/apps/federatedfilesharing/l10n/pt_PT.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Invalid Federated Cloud ID" : "Id. de Nuvem Federada Inválida",
    "Server to server sharing is not enabled on this server" : "Partilha servidor-para-servidor não está ativa neste servidor",
    "Couldn't establish a federated share." : "Não foi possível estabelecer uma partilha federada.",
    "Couldn't establish a federated share, maybe the password was wrong." : "Não foi possível estabelecer a partilha federada, a palavra-passe talvez esteja incorreta.",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "Pedido de Partilha Federada enviado, irá receber o convite. Confira as suas notificações.",
    "File is already shared with %s" : "O ficheiro já foi partilhado com %s",
    "Could not find share" : "Não foi possível encontrar partilha",
    "Federated sharing" : "Partilha Federada",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Recebeu {share} como uma partilha remota de {user} (em nome de {behalf})",
    "You received {share} as a remote share from {user}" : "Recebeu {share} como uma partilha remota de {user}",
    "Accept" : "Aceitar",
    "Decline" : "Recusar",
    "Federated Cloud Sharing" : "Partilha de Nuvem Federada",
    "Sharing" : "Partilha",
    "Federated file sharing" : "Partilha federada de ficheiros",
    "Provide federated file sharing across servers" : "Permita a partilha federada de ficheiros entre servidores",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Partilhe comigo através da minha Id. da Nuvem Federada #Nextcloud",
    "Copy to clipboard" : "Copiar para área de transferência",
    "Copied!" : "Copiado!",
    "Federated Cloud" : "Nuvem Federada",
    "Share it so your friends can share files with you:" : "Partilhe para que os seus amigos possam partilhar ficheiros consigo:",
    "Add to your website" : "Adicione ao seu site da Web",
    "Share with me via Nextcloud" : "Partilhe comigo via Nextcloud",
    "HTML Code:" : "Código HTML:",
    "Cancel" : "Cancelar",
    "Add remote share" : "Adicionar partilha remota",
    "Remote share" : "Partilha remota",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Pretende adicionar a partilha remota {name} de {owner}@{remote}?",
    "Remote share password" : "Palavra-passe da partilha remota",
    "Your Federated Cloud ID:" : "A sua id. da Nuvem Federada:",
    "Twitter" : "Twitter"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
